==> vtours-websitedatamodel-1.0.1-590473.zip: src/Vtours/Website/Model/Stage/Element/TitleText.php <==
<?php
/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license is a violation of the license agreement
 * and will be prosecuted by civil and criminal law.
 *
 * @copyright 2017 Lifestyle Webconsulting GmbH
 * @link      www.life-style.de
 */

namespace Vtours\Website\Model\Stage\Element;

/**
 * Class TitleText
 *
 * @package Vtours\Website\Model\Stage\Element
 */
class TitleText
{

    /**
     * @var string
     */
    private $title;

    /**
     * @var string
     */
    private $content;

    /**
     * @var string
     */
    private $additionalContent;

    /**
     * @var Link
     */
    private $link;

    /**
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * @param string $title
     *
     * @return $this
     */
    public function setTitle($title)
    {
        $this->title = $title;

        return $this;
    }

    /**
     * @return string
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * @param string $content
     *
     * @return $this
     */
    public function setContent($content)
    {
        $this->content = $content;

        return $this;
    }

    /**
     * @return string
     */
    public function getAdditionalContent()
    {
        return $this->additionalContent;
    }

    /**
     * @param string $additionalContent
     *
     * @return TitleText
     */
    public function setAdditionalContent($additionalContent)
    {
        $this->additionalContent = $additionalContent;

        return $this;
    }

    /**
     * @return Link
     */
    public function getLink()
    {
        return $this->link;
    }

    /**
     * @param Link $link
     *
     * @return TitleText
     */
    public function setLink($link)
    {
        $this->link = $link;

        return $this;
    }
}

==> vtours-websitedatamodel-1.1.1-0041ab.zip: src/Vtours/Website/Model/Stage/Element/TitleText.php <==
<?php
/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license is a violation of the license agreement
 * and will be prosecuted by civil and criminal law.
 *
 * @copyright 2017 Lifestyle Webconsulting GmbH
 * @link      www.life-style.de
 */

namespace Vtours\Website\Model\Stage\Element;

/**
 * Class TitleText
 *
 * @package Vtours\Website\Model\Stage\Element
 */
class TitleText
{

    /**
     * @var string
     */
    private $title;

    /**
     * @var string
     */
    private $content;

    /**
     * @var string
     */
    private $additionalContent;

    /**
     * @var Link
     */
    private $link;

    /**
     * @var Image
     */
    private $image;

    /**
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * @param string $title
     *
     * @return $this
     */
    public function setTitle($title)
    {
        $this->title = $title;

        return $this;
    }

    /**
     * @return string
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * @param string $content
     *
     * @return $this
     */
    public function setContent($content)
    {
        $this->content = $content;

        return $this;
    }

    /**
     * @return string
     */
    public function getAdditionalContent()
    {
        return $this->additionalContent;
    }

    /**
     * @param string $additionalContent
     *
     * @return TitleText
     */
    public function setAdditionalContent($additionalContent)
    {
        $this->additionalContent = $additionalContent;

        return $this;
    }

    /**
     * @return Link
     */
    public function getLink()
    {
        return $this->link;
    }

    /**
     * @param Link $link
     *
     * @return TitleText
     */
    public function setLink($link)
    {
        $this->link = $link;

        return $this;
    }

    /**
     * @return Image
     */
    public function getImage()
    {
        return $this->image;
    }

    /**
     * @param Image $image
     *
     * @return TitleText
     */
    public function setImage($image)
    {
        $this->image = $image;

        return $this;
    }
}
